import nav from "../../common/navbar/navbar.vue";
import baseinfoDialog from "./components/baseinfoDialog.vue";
import customergradeDialog from "./components/customergradeDialog.vue";
import customermainstoreDialog from "./components/customermainstoreDialog.vue";
import customersubstoreDialog from "./components/customersubstoreDialog.vue";
import defaultImg from "../../../static/img/default.png";
import { mapState } from "vuex";
import url from "../../components/axios/url";
import { doFetch, doFetchqs } from "../../components/axios/api";
import {
  checkFalse,
  checkStatus,
  checkSuccess
} from "../../../static/js/checkStatus";
export default {
  name: "customersDetail",
  data() {
    return {
      navpath: [
        { name: "首页", path: "" },
        { name: "客户列表", path: "/allCustomers" },
        { name: "客户详情", path: "" }
      ],
      pageName: "allCustomer", // 请求参数
      memberId: "",
      // 接口文档 http://yapi.gicdev.com/project/4941/interface/api/153659
      member: {
        // 会员基础信息
        memberProtocolInfo: {
          // 会员协议信息
          visitConsentPrivacyProtocolTime: null, // 微盟访问同意协议的时间
          loginConsentPrivacyProtocolTime: null, // 微盟登录同意协议的时间
          consentPrivacyProtocolTime: null // 达摩同意协议的时间
        },
        thirdImgUrl: "" // 头像
      },
      memberInfo: {}, // 会员卡信息
      extendInfo: { // 开卡字段、扩展字段
        openField: [],
        fieldList: []
      },
      tagAndRemarkInfo: {}, // 标签备注
      defaultImg,
      toggleTag: false, // 拓展信息展开按钮
      showFieldType: 1, // 1开卡拓展字段 2会员信息字段
      showClique: false, // 集团权限
      baseinfoDialogVisible: false, // 修改基本信息弹窗
      gradeDialogVisible: false, // 修改等级弹窗
      mainStoreDialogVisible: false, // 修改服务门店、专属导购弹窗
      subStoreDialogVisible: false, // 修改协管门店弹窗
      nationCodeList: [], // 手机区号列表
      gradeList: [], // 等级列表
      assistStoreList: [
        "杭州武林银泰",
        "杭州城wqeq西银泰",
        "杭州古墩路印象城",
        "杭州武林银泰"
      ],
      transactionRecordList: [
        { label: "门店消费", icon: "icon-mendianbaojiadan", key: "numOfSale" },
        { label: "达摩商城", icon: "", key: "wechatMallNum" },
        { label: "微盟订单", icon: "icon-weimeng", key: "weimobMallNum" },
        { label: "其他订单", icon: "icon-dingdan-copy", key: "otherMallNum" }
      ]
    };
  },
  filters: {
    customerTypeFilter: v => {
      switch (v) {
        case "wxOpenCarMember":
          return "微信会员";
          break;
        case "posMember":
          return "POS会员";
          break;
        default:
          return "非会员";
          break;
      }
    },
    genderFilter: v => {
      switch (v) {
        case 1:
          return "男";
          break;
        case 2:
          return "女";
          break;
        default:
          return "未知";
          break;
      }
    }
  },
  computed: {
    ...mapState(["showEditClique"])
  },
  created() {
    this.$store.commit("mutations-slide", false);
    this.memberId = this.$route.query.id;
  },
  mounted() {
    this.initData();
    this.getEnterpriseInfo();
    this.getcodeList();
    this.getGradeList();
  },
  methods: {
    updateImgUrl() {},
    initData() {
      this.loading = true;
      doFetch(url.memberLoadBaseDetail, {
        memberId: this.memberId,
        pageName: this.pageName
      })
        .then(res => {
          if (res.data.errorCode === 0) {
            const ret = res.data.result;
            this.member = Object.assign({}, ret.member);
            this.extendInfo = Object.assign({}, ret.extendInfo);
            this.memberInfo = Object.assign({}, ret.memberInfo);
          } else {
            checkFalse(res.data.message);
            return false;
          }
        })
        .catch(err => {
          checkStatus(err);
        })
        .finally(_ => (this.loading = false));
    },
    // 更新头像
    updateImgUrl() {
      doFetch(url.updateImgUrl, {
        memberId: this.memberId
      })
        .then(res => {
          if (res.data.errorCode === 0) {
            checkSuccess();
            const ret = res.data.result;
            this.member = Object.assign({}, this.member, {
              thirdImgUrl: !!ret.thirdImgUrl ? ret.thirdImgUrl : ""
            });
          } else {
            checkFalse(res.data.message);
          }
        })
        .catch(err => {
          checkStatus(err);
        });
    },
    // 集团配置
    getEnterpriseInfo() {
      doFetchqs(url.enterpriseInfo).then(res => {
        if (res.data.errorCode === 0) {
          this.showClique = res.data.result.enterpriseInfo.showClique;
        }
      });
    },
    // 手机区号列表
    getcodeList() {
      doFetch(url.codeList)
        .then(res => {
          if (res.data.errorCode === 0) {
            this.nationCodeList = res.data.result.nationCodeList.map(item => {
              item.dictName += ` +${item.dictCode}`;
              return {
                dictName: item.dictName,
                dictCode: item.dictCode
              };
            });
          } else {
            checkFalse(res.data.message);
          }
        })
        .catch(err => {
          checkStatus(err);
        });
    },
    // 等级列表
    getGradeList() {
      doFetch(url.gradeList)
        .then(res => {
          if (res.data.errorCode === 0) {
            this.gradeList = res.data.result || [];
          } else {
            checkFalse(res.data.message);
            return false;
          }
        })
        .catch(err => {
          checkStatus(err);
        });
    }
  },
  components: {
    "v-nav": nav,
    baseinfoDialog,
    customergradeDialog,
    customermainstoreDialog,
    customersubstoreDialog
  }
};
